pub struct Scene {Show 26 fields
data: GlobalModel,
globals_bind_group: GlobalsBindGroup,
camera: Camera,
camera_input_state: Vec2<f32>,
event_lights: Vec<EventLight>,
skybox: Skybox,
terrain: Terrain<TerrainChunk>,
pub debug: Debug,
pub lod: Lod,
loaded_distance: f32,
map_bounds: Vec2<f32>,
select_pos: Option<Vec3<i32>>,
light_data: Vec<Light>,
particle_mgr: ParticleMgr,
trail_mgr: TrailMgr,
figure_mgr: FigureMgr,
tether_mgr: TetherMgr,
pub sfx_mgr: SfxMgr,
pub music_mgr: MusicMgr,
ambience_mgr: AmbienceMgr,
integrated_rain_vel: f32,
pub wind_vel: Vec2<f32>,
pub interpolated_time_of_day: Option<f64>,
last_lightning: Option<(Vec3<f32>, f64)>,
local_time: f64,
pub debug_vectors_enabled: bool,
}Fields
data: GlobalModelglobals_bind_group: GlobalsBindGroupcamera: Cameracamera_input_state: Vec2<f32>event_lights: Vec<EventLight>skybox: Skyboxterrain: Terrain<TerrainChunk>debug: Debuglod: Lodloaded_distance: f32map_bounds: Vec2<f32>x coordinate is sea level (minimum height for any land chunk), and y coordinate is the maximum height above the mnimimum for any land chunk.
select_pos: Option<Vec3<i32>>light_data: Vec<Light>particle_mgr: ParticleMgrtrail_mgr: TrailMgrfigure_mgr: FigureMgrtether_mgr: TetherMgrsfx_mgr: SfxMgrmusic_mgr: MusicMgrambience_mgr: AmbienceMgrintegrated_rain_vel: f32wind_vel: Vec2<f32>interpolated_time_of_day: Option<f64>last_lightning: Option<(Vec3<f32>, f64)>local_time: f64debug_vectors_enabled: boolImplementations
Sourceimpl Scene
impl Scene
Sourcepub fn new(
renderer: &mut Renderer,
lazy_init: &mut SpriteRenderContextLazy,
client: &Client,
settings: &Settings,
) -> Self
pub fn new( renderer: &mut Renderer, lazy_init: &mut SpriteRenderContextLazy, client: &Client, settings: &Settings, ) -> Self
Create a new Scene with default parameters.
Sourcepub fn terrain(&self) -> &Terrain<TerrainChunk>
pub fn terrain(&self) -> &Terrain<TerrainChunk>
Get a reference to the scene’s terrain.
Sourcepub fn particle_mgr(&self) -> &ParticleMgr
pub fn particle_mgr(&self) -> &ParticleMgr
Get a reference to the scene’s particle manager.
Sourcepub fn figure_mgr(&self) -> &FigureMgr
pub fn figure_mgr(&self) -> &FigureMgr
Get a reference to the scene’s figure manager.
pub fn music_mgr(&self) -> &MusicMgr
Sourcepub fn camera_mut(&mut self) -> &mut Camera
pub fn camera_mut(&mut self) -> &mut Camera
Get a mutable reference to the scene’s camera.
Sourcepub fn set_select_pos(&mut self, pos: Option<Vec3<i32>>)
pub fn set_select_pos(&mut self, pos: Option<Vec3<i32>>)
Set the block position that the player is interacting with
pub fn select_pos(&self) -> Option<Vec3<i32>>
Sourcepub fn handle_input_event(&mut self, event: Event, client: &Client) -> bool
pub fn handle_input_event(&mut self, event: Event, client: &Client) -> bool
Handle an incoming user input event (e.g.: cursor moved, key pressed, window closed).
If the event is handled, return true.
pub fn handle_outcome( &mut self, outcome: &Outcome, scene_data: &SceneData<'_>, audio: &mut AudioFrontend, )
Sourcepub fn maintain(
&mut self,
renderer: &mut Renderer,
audio: &mut AudioFrontend,
scene_data: &SceneData<'_>,
client: &Client,
settings: &Settings,
mmap_face_north: bool,
)
pub fn maintain( &mut self, renderer: &mut Renderer, audio: &mut AudioFrontend, scene_data: &SceneData<'_>, client: &Client, settings: &Settings, mmap_face_north: bool, )
Maintain data such as GPU constant buffers, models, etc. To be called once per tick.
pub fn global_bind_group(&self) -> &GlobalsBindGroup
Sourcepub fn render(
&self,
drawer: &mut Drawer<'_>,
state: &State,
viewpoint_entity: EcsEntity,
tick: u64,
scene_data: &SceneData<'_>,
)
pub fn render( &self, drawer: &mut Drawer<'_>, state: &State, viewpoint_entity: EcsEntity, tick: u64, scene_data: &SceneData<'_>, )
Render the scene using the provided Drawer.
pub fn maintain_debug_hitboxes( &mut self, client: &Client, settings: &Settings, hitboxes: &mut HashMap<Entity, DebugShapeId>, tracks: &mut HashMap<Vec2<i32>, Vec<DebugShapeId>>, gizmos: &mut Vec<(DebugShapeId, Time, bool)>, )
pub fn maintain_debug_vectors( &mut self, client: &Client, lines: &mut PlayerDebugLines, )